@@ -8,12 +8,12 @@ from ...utils.env_keys import REPORT_ERROR_KEY
 
 @click.command()
 @click.option(
-    '--name',
+    '--build',
     'build_name',
-    help='build identifer',
+    help='build name',
     required=True,
     type=str,
-    metavar='BUILD_ID'
+    metavar='BUILD_NAME'
 )
 def session(build_name):
     token, org, workspace = parse_token()
@@ -31,7 +31,8 @@ def session(build_name):
         res.raise_for_status()
         session_id = res.json()['id']
 
-        click.echo(session_id)
+        # what we print here gets captured and passed to `--session` in later commands
+        click.echo("{}/{}".format(session_path, session_id))
         return session_id
 
     except Exception as e:
